@@ -37,9 +37,9 @@ hypervolume_thin <- function(hv, factor=NULL, num.points=NULL)
   
   hv_out <- hv
   
-  hv_out@RandomPoints <- rp[sample(1:nrow(rp),nrow(rp)*factor),]
+  hv_out@RandomPoints <- rp[sample(1:nrow(rp),nrow(rp)*factor),,drop=FALSE]
   
   hv_out@PointDensity <- hv@PointDensity * factor
   
   return(hv_out)
-}
\ No newline at end of file
+}
